package com.jiuqi.mde;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;

/* loaded from: com_jiuqi_mde.jar:com/jiuqi/mde/MDESqlLogger.class */
public class MDESqlLogger {
    private String _LogFilePath;
    private boolean _LogStackTrace;
    private boolean _LogInsert;
    private boolean _LogDelete;
    private boolean _LogUpdate;
    private int _CurrentSize;
    private FileWriter _FileWriter;
    private BufferedWriter _BufferedWriter;
    private static SimpleDateFormat TIME_FORMAT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss:SSS");
    private static SimpleDateFormat FILE_FORMAT = new SimpleDateFormat("MMdd_HHmmss_SSS");
    public static MDESqlLogger Sql_Logger = null;

    public MDESqlLogger(String logFilePath, boolean logStackTrace, boolean logInsert, boolean logDelete, boolean logUpdate) throws IOException {
        this._LogStackTrace = false;
        this._LogInsert = true;
        this._LogDelete = true;
        this._LogUpdate = true;
        this._LogFilePath = logFilePath;
        this._LogStackTrace = logStackTrace;
        this._LogInsert = logInsert;
        this._LogDelete = logDelete;
        this._LogUpdate = logUpdate;
        if (!this._LogFilePath.endsWith(File.separator)) {
            this._LogFilePath = String.valueOf(this._LogFilePath) + File.separator;
        }
        File directory = new File(this._LogFilePath);
        if (!directory.isDirectory()) {
            directory.mkdirs();
        }
        this._FileWriter = new FileWriter(getNextFile(), false);
        this._BufferedWriter = new BufferedWriter(this._FileWriter, 1048576);
    }

    public static String getLogTime() {
        return TIME_FORMAT.format(new Date());
    }

    public static String getStackTrace() {
        Exception e = new Exception("");
        StackTraceElement[] traces = e.getStackTrace();
        String result = "\"";
        for (StackTraceElement trace : traces) {
            String className = trace.getClassName();
            if (className.startsWith("jsp_servlet") || (className.startsWith("com.jiuqi") && !className.startsWith("com.jiuqi.mde"))) {
                result = String.valueOf(result) + trace.toString() + "\n";
            }
        }
        return String.valueOf(result) + "\"\n\r";
    }

    private String getNextFile() {
        return String.valueOf(this._LogFilePath) + FILE_FORMAT.format(new Date()) + ".log";
    }

    public void LogInsertSql(String sqlInfo) {
        if (this._LogInsert) {
            if (this._LogStackTrace) {
                sqlInfo = String.valueOf(sqlInfo) + getStackTrace();
            }
            LogSqlInfo(sqlInfo);
        }
    }

    public void LogDeleteSql(String sqlInfo) {
        if (this._LogDelete) {
            if (this._LogStackTrace) {
                sqlInfo = String.valueOf(sqlInfo) + getStackTrace();
            }
            LogSqlInfo(sqlInfo);
        }
    }

    public void LogUpdateSql(String sqlInfo) {
        if (this._LogUpdate) {
            if (this._LogStackTrace) {
                sqlInfo = String.valueOf(sqlInfo) + getStackTrace();
            }
            LogSqlInfo(sqlInfo);
        }
    }

    private synchronized void LogSqlInfo(String sqlInfo) {
        try {
            this._BufferedWriter.write(sqlInfo);
            this._CurrentSize += sqlInfo.length();
            if (this._CurrentSize > 16777216) {
                this._BufferedWriter.close();
                this._FileWriter.close();
                this._CurrentSize = 0;
                this._FileWriter = new FileWriter(getNextFile(), false);
                this._BufferedWriter = new BufferedWriter(this._FileWriter, 1048576);
            }
        } catch (IOException ex) {
            ex.printStackTrace();
        }
    }

    public synchronized void close() throws IOException {
        this._BufferedWriter.close();
        this._FileWriter.close();
    }

    public static void startSQLLog(String logFilePath, boolean logStackTrace, boolean logInsert, boolean logDelete, boolean logUpdate) throws IOException {
        if (Sql_Logger != null) {
            throw new IOException("跟踪已经开始!");
        }
        Sql_Logger = new MDESqlLogger(logFilePath, logStackTrace, logInsert, logDelete, logUpdate);
    }

    public static void stopSQLLog() throws IOException {
        if (Sql_Logger == null) {
            throw new IOException("跟踪还没有开始!");
        }
        MDESqlLogger temp = Sql_Logger;
        Sql_Logger = null;
        temp.close();
    }
}
